<?xml version="1.0" encoding="UTF-8"?>
<!--
	XSLT stylesheet: G2xml2Html
	Purpose: transforming any G2 XML (News Message, Items) to human readable HTML, including some validity checking
	(c) Copyright 2010 IPTC - www.iptc.org
	See the license agreement at the bottom of this file.
	Files:
		G2xml2Html_{version number}.xslt = this file
		G2xml2Html-resources-web.xslt = resourced for this XSLT based on files on the IPTC web server
		G2xml2Html-resources-local.xslt = resources  for this XSLT based on local files in the relative folder ..\specification\......
	Author: Michael Steidl
	History:
	v 1	2010-09-22/ms: public release version, derived from dev versions.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nar="http://iptc.org/std/nar/2006-10-01/">
	<!-- the two xsl:import elements below load resource files with alternative locations of the G2 XML Schema documentation files:
		web = on the IPTC web server
		local = on this PC in the relative folder ..\specification\......
		One of these two elements MUST be commented out and the other one be active!
-->
	<xsl:import href="G2xml2Html-resources-web.xslt"/>
<!--	<xsl:import href="G2xml2Html-resources-local.xslt"/> -->	
	<xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="no"/>
	<xsl:variable name="XSLTdocversion" select="'1'"/>
	<xsl:variable name="globalElemBackground" select="'lavender'"/>
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>G2 XML transformed to HTML</title>
				<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
				<style type="text/css">
				body {
					background : #005AAA;
					font-size: 0.8em;
					font-family: sans-serif;
				}
				.containerMain {
					background: #FFF;
					width: 930px;
					padding: 10px;
				}
				span.xmlelemname {
					background: firebrick;
					color: #FFFFFF;
					padding-left:4px;
					padding-right:4px;
				}
				span.xmlelemvalue {
					color: #00008B;
				}
				span.xmlattrname {
					background: darkslateblue;
					color: #FFFFFF;
					padding-left:4px;
					padding-right:4px;			
				}
				span.xmlattrvalue {
					color: #00008B;
				}
				.warning1 {
					color: crimson;
				}
				.nowarning1 {
					color: limegreen;
					font-weight: bold;
				}
				</style>
			</head>
			<body>
				<div class="containerMain">
				<h3>XSLT stylesheet G2xml2Html, v <xsl:value-of select="$XSLTdocversion"/> - provided by IPTC (<a href="www.iptc.org" target="_blank">www.iptc.org</a>)
				</h3>
				<h1>HTML representation of a G2 XML document:</h1>
				<xsl:choose>
					<xsl:when test="/nar:newsMessage">
						<h2>A News Message - with item(s)</h2>
					</xsl:when>
					<xsl:when test="/nar:newsItem">
						<h2>A News Item</h2>
						<xsl:apply-templates select="/*" mode="inHeader"/>
					</xsl:when>
					<xsl:when test="/nar:conceptItem">
						<h2>A Concept Item</h2>
						<xsl:apply-templates select="/*" mode="inHeader"/>
					</xsl:when>
					<xsl:when test="/nar:knowledgeItem">
						<h2>A Knowledge Item</h2>
						<xsl:apply-templates select="/*" mode="inHeader"/>
					</xsl:when>
					<xsl:when test="/nar:packageItem">
						<h2>A Package Item</h2>
						<xsl:apply-templates select="/*" mode="inHeader"/>
					</xsl:when>
					<xsl:when test="/nar:planningItem">
						<h2>A Planning Item</h2>
						<xsl:apply-templates select="/*" mode="inHeader"/>
					</xsl:when>
				</xsl:choose>
				<!-- Template for a LIST OF WARNINGS is called -->
				<xsl:call-template name="ListOfWarnings"/>
				<!-- LIST OF ELEMENTS AND ATTRIBUTES is created -->
				<h3>List of all elements and attributes which are present and their values</h3>
				<ul style="padding-left: 15px; width: 800px; list-style-type: square; ">
					<li>A bold blue box indicates a News Message, which wraps item(s).</li>
					<li>A dashed blue box indicates the itemSet inside a News Message</li>
					<li>A blue double box encapsulates an item.</li>
					<li>Double boxes in dark red indicate the major structures inside an item, in most cases wrappers for a set of child elements. The top line of these double boxes shows a short description of the element and provides a link to its XML Schema documentation which resides on <xsl:value-of select="$docsource"/> .<br />For major structures which are shared across all types of G2 items the documentation link points to this structure in the G2 Concept Item.</li>
					<li>Each element is shown in a single line box, including its <span class="xmlelemname">name</span> and all its <span class="xmlattrname">attributes</span>, both with values if they are present.</li>
				</ul>
				<div style="background:	powderblue; width: 925px;">
					<xsl:apply-templates select="*">
						<!-- start with no conformance level -->
						<xsl:with-param name="paramConfLevel"><xsl:value-of select="''"/></xsl:with-param>
						<!-- start with no type of item set -->
						<xsl:with-param name="paramItemType"><xsl:value-of select="''"/></xsl:with-param>
					</xsl:apply-templates>
				</div>
				</div>
			</body>
		</html>
	</xsl:template>
	<!-- 
		********** Template for elements ********** 
-->
	<xsl:template match="*">
		<!-- manage the params -->
		<xsl:param name="paramConfLevel"/>
		<xsl:param name="paramItemType"/>
		<!-- add some business logic: 
			if the conformance level is already set: keep it untouched
			if the conformance level is not set yet: if this element is one of the root elements of a G2 item then set the conformance level according to the @conformance attribute
			The variable $localItemType should be used by this template
		-->
		<xsl:variable name="localConfLevel">
			<xsl:choose>
				<xsl:when test="$paramConfLevel != ''"><xsl:value-of select="$paramConfLevel"/></xsl:when>
				<xsl:otherwise>
						<xsl:if test="(local-name() = 'conceptItem') or (local-name() = 'knowledgeItem') or (local-name() = 'newsItem') or (local-name() = 'packageItem') or (local-name() = 'planningItem')">
							<xsl:choose>
								<xsl:when test="./@conformance='power'"><xsl:value-of select="'PCL'"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="'CCL'"/></xsl:otherwise>
							</xsl:choose>
						</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- add some business logic: 
			if the type of the item is already set: keep it untouched
			if the type of the item is not set yet: if this element is one of the root elements of a G2 item then set the type of the item accordingly 
			The variable $localItemType should be used by this template
		-->
		<xsl:variable name="localItemType">
			<xsl:choose>
				<xsl:when test="$paramItemType != ''"><xsl:value-of select="$paramItemType"/></xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="local-name() = 'conceptItem'">
							<xsl:value-of select="'conceptItem'"/>
						</xsl:when>
						<xsl:when test="local-name() = 'knowledgeItem'">
							<xsl:value-of select="'knowledgeItem'"/>
						</xsl:when>
						<xsl:when test="local-name() = 'newsItem'">
							<xsl:value-of select="'newsItem'"/>
						</xsl:when>
						<xsl:when test="local-name() = 'packageItem'">
							<xsl:value-of select="'packageItem'"/>
						</xsl:when>
						<xsl:when test="local-name() = 'planningItem'">
							<xsl:value-of select="'planningItem'"/>
						</xsl:when>
						</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- ********** 
			Below: the business logic for the variable divBorderStyle1 
-->
		<xsl:variable name="divBorderStyle1">
			<xsl:choose>
				<xsl:when test="local-name() = 'newsMessage'">
					<xsl:value-of select="'border: 5px solid blue; margin: 5px;  background:lightgrey;'"/>
				</xsl:when>
				<xsl:when test="local-name() = 'itemSet'">
					<xsl:value-of select="'border: 3px dashed blue; margin: 5px;  background:lightgrey;'"/>
				</xsl:when>
				<xsl:when test="local-name() = 'conceptItem'">
					<xsl:value-of select="'border: 4px double blue; margin: 5px; background:lightblue;'"/>
				</xsl:when>
				<xsl:when test="local-name() = 'knowledgeItem'">
					<xsl:value-of select="'border: 4px double blue; margin: 5px; background:lightblue;'"/>
				</xsl:when>
				<xsl:when test="local-name() = 'newsItem'">
					<xsl:value-of select="'border: 4px double blue; margin: 5px; background:lightblue;'"/>
				</xsl:when>
				<xsl:when test="local-name() = 'packageItem'">
					<xsl:value-of select="'border: 4px double blue; margin: 5px; background:lightblue;'"/>
				</xsl:when>
				<xsl:when test="local-name() = 'planningItem'">
					<xsl:value-of select="'border: 4px double blue; margin: 5px; background:lightblue;'"/>
				</xsl:when>
				<xsl:when test="local-name() = 'catalogRef'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px; background:palegreen; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'catalog'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px; background:mediumaquamarine; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'rightsInfo'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px; background:tan; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'itemMeta'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px; background:wheat; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'contentMeta'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px; background:palegoldenrod; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'partMeta'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px;  background:lightgoldenrodyellow; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'assert'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px;  background:khaki; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'inlineRef'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px;  background:peachpuff; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'contentSet'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px;  background:lightsalmon; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'concept'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px;  background:lightpink; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'conceptSet'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px;  background:lightsalmon; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'groupSet'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px;  background:lightsalmon; '"/>
				</xsl:when>
				<xsl:when test="local-name() = 'newsCoverageSet'">
					<xsl:value-of select="'border: 4px double maroon; margin: 5px;  background:lightsalmon; '"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'border: 1px solid maroon; margin: 5px; '"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- ********** 
			Below: the business logic for the variable wrapperDescr 
-->
		<xsl:variable name="wrapperDescr">
			<xsl:choose>
				<xsl:when test="local-name() = 'newsMessage'">
					<xsl:value-of select="$newsMessage_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'itemSet'">
					<xsl:value-of select="$itemSet_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'conceptItem'">
					<xsl:value-of select="$conceptItem_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'knowledgeItem'">
					<xsl:value-of select="$knowledgeItem_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'newsItem'">
					<xsl:value-of select="$newsItem_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'packageItem'">
					<xsl:value-of select="$packageItem_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'planningItem'">
					<xsl:value-of select="$planningItem_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'catalogRef'">
					<xsl:value-of select="$catalogRef_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'catalog'">
					<xsl:value-of select="$catalog_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'rightsInfo'">
					<xsl:value-of select="$rightsInfo_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'itemMeta'">
					<xsl:value-of select="$itemMeta_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'contentMeta'">
					<xsl:choose>
						<xsl:when test="$localItemType = 'conceptItem' "><xsl:value-of select="$contentMeta-inCI_descr"/></xsl:when>
						<xsl:when test="$localItemType = 'knowledgeItem' "><xsl:value-of select="$contentMeta-inKI_descr"/></xsl:when>
						<xsl:when test="$localItemType = 'newsItem' "><xsl:value-of select="$contentMeta-inNI_descr"/></xsl:when>
						<xsl:when test="$localItemType = 'packageItem' "><xsl:value-of select="$contentMeta-inPGI_descr"/></xsl:when>
						<xsl:when test="$localItemType = 'planningItem' "><xsl:value-of select="$contentMeta-inPLI_descr"/></xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="local-name() = 'partMeta'">
					<xsl:choose>
						<xsl:when test="$localItemType = 'knowledgeItem' "><xsl:value-of select="$partMeta-inKI_descr"/></xsl:when>
						<xsl:when test="$localItemType = 'newsItem' "><xsl:value-of select="$partMeta-inNI_descr"/></xsl:when>
						<xsl:when test="$localItemType = 'packageItem' "><xsl:value-of select="$partMeta-inPGI_descr"/></xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="local-name() = 'assert'">
					<xsl:value-of select="$assert_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'inlineRef'">
					<xsl:value-of select="$inlineRef_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'contentSet'">
					<xsl:value-of select="$contentSet_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'concept'">
					<xsl:value-of select="$concept_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'conceptSet'">
					<xsl:value-of select="$conceptSet_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'groupSet'">
					<xsl:value-of select="$groupSet_descr"/>
				</xsl:when>
				<xsl:when test="local-name() = 'newsCoverageSet'">
					<xsl:value-of select="$newsCoverageSet_descr"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!-- ********** 
			Below: the business logic for the variable wrapperDocURL 
-->
		<xsl:variable name="wrapperDocURL">
			<xsl:choose>
				<xsl:when test="local-name() = 'newsMessage'">
					<xsl:value-of select="$newsMessage_docurlCCL"/>
				</xsl:when>
				<xsl:when test="local-name() = 'itemSet'">
					<xsl:value-of select="$itemSet_docurlCCL"/>
				</xsl:when>
				<xsl:when test="local-name() = 'conceptItem'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$conceptItem_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$conceptItem_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'knowledgeItem'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$knowledgeItem_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$knowledgeItem_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'newsItem'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$newsItem_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$newsItem_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'packageItem'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$packageItem_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$packageItem_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'planningItem'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$planningItem_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$planningItem_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'catalogRef'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$catalogRef_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$catalogRef_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'catalog'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$catalog_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$catalog_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'rightsInfo'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$rightsInfo_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$rightsInfo_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'itemMeta'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$itemMeta_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$itemMeta_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'contentMeta'">
					<xsl:choose>
						<xsl:when test="$localItemType = 'conceptItem' ">
							<xsl:choose>
								<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$contentMeta-inCI_docurlCCL"/></xsl:when>
								<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$contentMeta-inCI_docurlPCL"/></xsl:when>
							</xsl:choose>	
						</xsl:when>
						<xsl:when test="$localItemType = 'knowledgeItem' ">
							<xsl:choose>
								<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$contentMeta-inKI_docurlCCL"/></xsl:when>
								<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$contentMeta-inKI_docurlPCL"/></xsl:when>
							</xsl:choose>	
						</xsl:when>
						<xsl:when test="$localItemType = 'newsItem' ">
							<xsl:choose>
								<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$contentMeta-inNI_docurlCCL"/></xsl:when>
								<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$contentMeta-inNI_docurlPCL"/></xsl:when>
							</xsl:choose>	
						</xsl:when>
						<xsl:when test="$localItemType = 'packageItem' ">
							<xsl:choose>
								<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$contentMeta-inPGI_docurlCCL"/></xsl:when>
								<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$contentMeta-inPGI_docurlPCL"/></xsl:when>
							</xsl:choose>	
						</xsl:when>
						<xsl:when test="$localItemType = 'planningItem' ">
							<xsl:choose>
								<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$contentMeta-inPLI_docurlCCL"/></xsl:when>
								<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$contentMeta-inPLI_docurlPCL"/></xsl:when>
							</xsl:choose>	
						</xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="local-name() = 'partMeta'">
					<xsl:choose>
						<xsl:when test="$localItemType = 'knowledgeItem' ">
							<xsl:choose>
								<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$partMeta-inKI_docurlCCL"/></xsl:when>
								<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$partMeta-inKI_docurlPCL"/></xsl:when>
							</xsl:choose>	
						</xsl:when>
						<xsl:when test="$localItemType = 'newsItem' ">
							<xsl:choose>
								<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$partMeta-inNI_docurlCCL"/></xsl:when>
								<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$partMeta-inNI_docurlPCL"/></xsl:when>
							</xsl:choose>	
						</xsl:when>
						<xsl:when test="$localItemType = 'packageItem' ">
							<xsl:choose>
								<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$partMeta-inPGI_docurlCCL"/></xsl:when>
								<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$partMeta-inPGI_docurlPCL"/></xsl:when>
							</xsl:choose>	
						</xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="local-name() = 'assert'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$assert_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$assert_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'inlineRef'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$inlineRef_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$inlineRef_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'contentSet'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$contentSet_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$contentSet_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'concept'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$concept_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$concept_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'conceptSet'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$conceptSet_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$conceptSet_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'groupSet'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$groupSet_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$groupSet_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
				<xsl:when test="local-name() = 'newsCoverageSet'">
					<xsl:choose>
						<xsl:when test="$localConfLevel = 'CCL'"><xsl:value-of select="$newsCoverageSet_docurlCCL"/></xsl:when>
						<xsl:when test="$localConfLevel = 'PCL'"><xsl:value-of select="$newsCoverageSet_docurlPCL"/></xsl:when>
					</xsl:choose>	
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!-- 
			here starts the block for displaying/rendering the content of $this element 
		-->
		<div>
			<xsl:attribute name="style"><xsl:value-of select="string($divBorderStyle1)"/></xsl:attribute>
			<xsl:if test="($wrapperDescr)">
				<p style="padding-left: 5px; margin-top:2px; margin-bottom:1px; font-size:1.4em; color:#00008B; ">
					<xsl:choose>
						<xsl:when test="($wrapperDocURL) and (string($wrapperDocURL) != '') ">
							<a style="color: maroon;">
								<xsl:attribute name="href"><xsl:value-of select="$wrapperDocURL"/></xsl:attribute>
								<xsl:attribute name="target"><xsl:value-of select="'_blank'"/></xsl:attribute>
								<xsl:value-of select="$wrapperDescr"/>
							</a>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$wrapperDescr"/>
						</xsl:otherwise>
					</xsl:choose>
				</p>
			</xsl:if>
			<p style="padding-left: 5px; margin-top:2px; margin-bottom:1px;">
				<span class="xmlelemname">
					<xsl:value-of select="local-name()"/>
				</span>
				<xsl:if test="normalize-space(text()) != '' "> = "<span class="xmlelemvalue">
						<xsl:value-of select="text()"/>
					</span>"
				</xsl:if>
				<xsl:apply-templates select="@*"/>
			</p>
			<xsl:apply-templates select="*">
				<xsl:with-param name="paramConfLevel"><xsl:value-of select="$localConfLevel"/></xsl:with-param>
				<xsl:with-param name="paramItemType"><xsl:value-of select="$localItemType"/></xsl:with-param>
			</xsl:apply-templates>
		</div>
	</xsl:template>
	<!-- 
		********** Template for attributes ********** 
-->
	<xsl:template match="@*">
		<br/>
		<span class="xmlattrname">
			<xsl:value-of select="local-name()"/>
		</span> = "<span class="xmlattrvalue">
			<xsl:value-of select="."/>
		</span>"
	</xsl:template>
	<!-- 
		********** Template for ...Item root elements ********** 
-->
	<xsl:template match="nar:newsItem|nar:conceptItem|nar:knowledgeItem|nar:packageItem|nar:planningItem" mode="inHeader">
		<h3>With a @guid = "<xsl:value-of select="./@guid"/>" and @version = <xsl:value-of select="./@version"/>
		</h3>
		<p>
		Core information about the item: <br/>
		Applicable G2-Standard = "<xsl:value-of select="./@standard"/>", version = "<xsl:value-of select="./@standardversion"/>"
			<br/>
		G2 Conformance Level = "<xsl:value-of select="./@conformance"/>"
		</p>
	</xsl:template>
	<!-- 
		********** Template for List Of Warnings ********** 
-->
	<xsl:template name="ListOfWarnings">
		<!-- LIST OF WARNINGS -->
		<div style="border: 4px double crimson; margin: 5px; width: 850px;">
			<div style="padding-left: 5px;">
				<h3>List of G2-warnings from parsing the XML</h3>
				<!-- first: the testing sequence -->
				<xsl:variable name="test1">
					<xsl:choose>
						<xsl:when test="not(//nar:itemMeta/nar:itemClass/@qcode)">Mandatory attribute @qcode of "itemClass" is missing!</xsl:when>
						<xsl:otherwise>PASSED1</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="test1s1">
					<xsl:choose>
						<xsl:when test="//nar:itemMeta/nar:itemClass/@qcode = '' ">Mandatory QCode value for "itemClass" is missing!</xsl:when>
						<xsl:otherwise>PASSED1s1</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="test2">
					<xsl:choose>
						<xsl:when  test="not(//nar:itemMeta/nar:itemClass)">Mandatory element "itemClass" is missing!</xsl:when>
						<xsl:otherwise>PASSED2</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="test3">
					<xsl:choose>
						<xsl:when test="(//nar:itemMeta/nar:provider)">
							<xsl:choose>
								<xsl:when test="(not(//nar:itemMeta/nar:provider/@qcode) or (//nar:itemMeta/nar:provider/@qcode = '')) ">
									<xsl:choose>
										<xsl:when test="(not(//nar:itemMeta/nar:provider/@literal) or (//nar:itemMeta/nar:provider/@literal = '')) ">Mandatory value in @qcode or @literal for "provider" is missing!</xsl:when>
										<xsl:otherwise>PASSED3</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>PASSED3</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>Mandatory element "provider" is missing</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="test4">
					<xsl:choose>
						<xsl:when test="//nar:itemMeta/nar:versionCreated = '' ">Mandatory date value for "versionCreated" is missing!</xsl:when>
						<xsl:otherwise>PASSED4</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="test5">
					<xsl:choose>
						<xsl:when test="not(//nar:itemMeta/nar:versionCreated)">Mandatory element "versionCreated" is missing!</xsl:when>
						<xsl:otherwise>PASSED5</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="test6">
					<xsl:choose>
						<xsl:when test="not(//nar:catalogRef)">
							<xsl:if test="not(//nar:catalog/nar:scheme)">Neither a "catalogRef" nor a "catalog" (with at least one "scheme") exists.</xsl:if>
						</xsl:when>
						<xsl:when test="//nar:catalogRef/@href = '' ">The existing "catalogRef" requires a @href attribute value.</xsl:when>
						<xsl:otherwise>PASSED6</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="test7">
					<xsl:choose>
						<xsl:when test="(//nar:contentSet)">
							<xsl:choose>
								<xsl:when test="count(//nar:contentSet[not(child::*)]) > 0">A contentSet in a News Item has no child elements - strange.</xsl:when>
								<xsl:otherwise>PASSED7</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>PASSED7</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="test8">
					<xsl:choose>
						<xsl:when test="(//nar:conceptSet)">
							<xsl:choose>
								<xsl:when test="count(//nar:conceptSet[not(child::*)]) > 0">A conceptSet in a Knowledge Item has no child elements - strange.</xsl:when>
								<xsl:otherwise>PASSED8</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>PASSED8</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>	
				<!-- secondly: the display sequence -->
				<xsl:choose>
					<xsl:when test="(starts-with($test1, 'PASSED')) and (starts-with($test1s1, 'PASSED')) and (starts-with($test2, 'PASSED')) and (starts-with($test3, 'PASSED')) and (starts-with($test4, 'PASSED')) and (starts-with($test5, 'PASSED')) and (starts-with($test6, 'PASSED')) and (starts-with($test7, 'PASSED')) and (starts-with($test8, 'PASSED'))"><span class="nowarning1">NO warning(s) detected</span></xsl:when>
					<xsl:otherwise>
						<xsl:if test="not( starts-with($test2, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test2"/><br /></span></xsl:if>
						<xsl:if test="not( starts-with($test1, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test1"/><br /></span></xsl:if>
						<xsl:if test="not( starts-with($test1s1, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test1s1"/><br /></span></xsl:if>
						<xsl:if test="not( starts-with($test3, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test3"/><br /></span></xsl:if>
						<xsl:if test="not( starts-with($test4, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test4"/><br /></span></xsl:if>
						<xsl:if test="not( starts-with($test5, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test5"/><br /></span></xsl:if>
						<xsl:if test="not( starts-with($test6, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test6"/><br /></span></xsl:if>
						<xsl:if test="not( starts-with($test7, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test7"/><br /></span></xsl:if>
						<xsl:if test="not( starts-with($test8, 'PASSED' ))"><span class="warning1"><xsl:value-of select="$test8"/><br /></span></xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</div>
		</div>
	</xsl:template>
</xsl:stylesheet>
<!--
IPTC - International Press Telecommunications Council
20 Garrick Street, London WC2E 9BT, United Kingdom 
www.iptc.org

Non-Exclusive License Agreement for International Press
Telecommunications Council Specifications and Related Documentation

IMPORTANT: International Press Telecommunications Council (IPTC)
standard specifications for news (the Specifications) and supporting
software, documentation, technical reports, web sites and other
material related to the Specifications (the Materials) including the
document accompanying this license (the Document), whether in a paper
or electronic format, are made available to you subject to the terms
stated below. By obtaining, using and/or copying the Specifications or
Materials, you (the licensee) agree that you have read, understood,
and will comply with the following terms and conditions.

1. The Specifications and Materials are licensed for use only on the
condition that you agree to be bound by the terms of this license.
Subject to this and other licensing requirements contained herein, you
may, on a non-exclusive basis, use the Specifications and Materials.

2. The IPTC openly provides the Specifications and Materials for
voluntary use by individuals, partnerships, companies, corporations,
organizations and any other entity for use at the entity's own risk.
This disclaimer, license and release is intended to apply to the IPTC,
its officers, directors, agents, representatives, members,
contributors, affiliates, contractors, or co-venturers acting jointly
or severally.

3. The Document and translations thereof may be copied and furnished
to others, and derivative works that comment on or otherwise explain
it or assist in its implementation may be prepared, copied, published
and distributed, in whole or in part, without restriction of any kind,
provided that the copyright and license notices and references to the
IPTC appearing in the Document and the terms of this Specifications
License Agreement are included on all such copies and derivative
works. Further, upon the receipt of written permission from the IPTC,
the Document may be modified for the purpose of developing
applications that use IPTC Specifications or as required to translate
the Document into languages other than English.

4. Any use, duplication, distribution, or exploitation of the Document
and Specifications and Materials in any manner is at your own risk.

5. NO WARRANTY, EXPRESSED OR IMPLIED, IS MADE REGARDING THE ACCURACY,
ADEQUACY, COMPLETENESS, LEGALITY, RELIABILITY OR USEFULNESS OF ANY
INFORMATION CONTAINED IN THE DOCUMENT OR IN ANY SPECIFICATION OR OTHER
PRODUCT OR SERVICE PRODUCED OR SPONSORED BY THE IPTC. THE DOCUMENT AND
THE INFORMATION CONTAINED HEREIN AND INCLUDED IN ANY SPECIFICATION OR
OTHER PRODUCT OR SERVICE OF THE IPTC IS PROVIDED ON AN "AS IS" BASIS.
THE IPTC DISCLAIMS ALL WARRANTIES OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING, BUT NOT LIMITED TO, ANY ACTUAL OR ASSERTED WARRANTY OF NON-
INFRINGEMENT OF PROPRIETARY RIGHTS, MERCHANTABILITY, OR FITNESS FOR A
PARTICULAR PURPOSE. NEITHER THE IPTC NOR ITS CONTRIBUTORS SHALL BE
HELD LIABLE FOR ANY IMPROPER OR INCORRECT USE OF INFORMATION. NEITHER
THE IPTC NOR ITS CONTRIBUTORS ASSUME ANY RESPONSIBILITY FOR ANYONE'S
USE OF INFORMATION PROVIDED BY THE IPTC. IN NO EVENT SHALL THE IPTC OR
ITS CONTRIBUTORS BE LIABLE TO ANYONE FOR DAMAGES OF ANY KIND,
INCLUDING BUT NOT LIMITED TO, COMPENSATORY DAMAGES, LOST PROFITS, LOST
DATA OR ANY FORM OF SPECIAL, INCIDENTAL, INDIRECT, CONSEQUENTIAL OR
PUNITIVE DAMAGES OF ANY KIND WHETHER BASED ON BREACH OF CONTRACT OR
WARRANTY, TORT, PRODUCT LIABILITY OR OTHERWISE.

6. The IPTC takes no position regarding the validity or scope of any
Intellectual Property or other rights that might be claimed to pertain
to the implementation or use of the technology described in the
Document or the extent to which any license under such rights might or
might not be available. The IPTC does not represent that it has made
any effort to identify any such rights. Copies of claims of rights
made available for publication, assurances of licenses to be made
available, or the result of an attempt made to obtain a general
license or permission for the use of such proprietary rights by
implementers or users of the Specifications and Materials, can be
obtained from the Managing Director of the IPTC.

7. By using the Specifications and Materials including the Document in
any manner or for any purpose, you release the IPTC from all
liabilities, claims, causes of action, allegations, losses, injuries,
damages, or detriments of any nature arising from or relating to the
use of the Specifications, Materials or any portion thereof. You
further agree not to file a lawsuit, make a claim, or take any other
formal or informal legal action against the IPTC, resulting from your
acquisition, use, duplication, distribution, or exploitation of the
Specifications, Materials or any portion thereof. Finally, you hereby
agree that the IPTC is not liable for any direct, indirect, special or
consequential damages arising from or relating to your acquisition,
use, duplication, distribution, or exploitation of the Specifications,
Materials or any portion thereof.

8. Specifications and Materials may be downloaded or copied provided
that ALL copies retain the ownership, copyright and license notices.

9. Materials may not be edited, modified, or presented in a context
that creates a misleading or false impression or statement as to the
positions, actions, or statements of the IPTC.

10. The name and trademarks of the IPTC may not be used in
advertising, publicity, or in relation to products or services and
their names without the specific, written prior permission of the
IPTC. Any permitted use of the trademarks of the IPTC, whether
registered or not, shall be accompanied by an appropriate mark and
attribution, as agreed with the IPTC.

11. Specifications may be extended by both members and non-members to
provide additional functionality (Extended Specifications) provided
that there is a clear recognition of the IPTC IP and its ownership in
the Extended Specifications and the related documentation and provided
that the extensions are clearly identified and provided that a
perpetual license is granted by the creator of the Extended
Specifications for other members and non-members to use the Extended
Specifications and to continue extensions of the Extended
Specifications. The IPTC does not waive any of its rights in the
Specifications and Materials in this context. The Extended
Specifications may be considered the intellectual property of their
creator. The IPTC expressly disclaims any responsibility for damage
caused by an extension to the Specifications.

12. Specifications and Materials may be included in derivative work of
both members and non-members provided that there is a clear
recognition of the IPTC IP and its ownership in the derivative work
and its related documentation. The IPTC does not waive any of its
rights in the Specifications and Materials in this context. Derivative
work in its entirety may be considered the intellectual property of
the creator of the work .The IPTC expressly disclaims any
responsibility for damage caused when its IP is used in a derivative
context.

13. This Specifications License Agreement is perpetual subject to your
conformance to the terms of this Agreement. The IPTC may terminate
this Specifications License Agreement immediately upon your breach of
this Agreement and, upon such termination you will cease all use,
duplication, distribution, and/or exploitation in any manner of the
Specifications and Materials.

14. This Specifications License Agreement reflects the entire
agreement of the parties regarding the subject matter hereof and
supersedes all prior agreements or representations regarding such
matters, whether written or oral. To the extent any portion or
provision of this Specifications License Agreement is found to be
illegal or unenforceable, then the remaining provisions of this
Specifications License Agreement will remain in full force and effect
and the illegal or unenforceable provision will be construed to give
it such effect as it may properly have that is consistent with the
intentions of the parties.

15. This Specifications License Agreement may only be modified in
writing signed by an authorized representative of the IPTC.

16. This Specifications License Agreement is governed by the law of
United Kingdom, as such law is applied to contracts made and fully
performed in the United Kingdom. Any disputes arising from or relating
to this Specifications License Agreement will be resolved in the
courts of the United Kingdom. You consent to the jurisdiction of such
courts over you and covenant not to assert before such courts any
objection to proceeding in such forums.

IF YOU DO NOT AGREE TO THESE TERMS YOU MUST CEASE ALL USE OF THE
SPECIFICATIONS AND MATERIALS NOW. IF YOU HAVE ANY QUESTIONS ABOUT
THESE TERMS, PLEASE CONTACT THE MANAGING DIRECTOR OF THE INTERNATIONAL
PRESS TELECOMMUNICATION COUNCIL. AS OF THE DATE OF THIS REVISION OF
THIS SPECIFICATIONS LICENSE AGREEMENT YOU MAY CONTACT THE IPTC at
http://www.iptc.org.

License agreement version of: 30 January 2006
-->
